import type { Redis, Cluster } from "ioredis";
declare global {
    var __wzfConfig: WzfConfig;
    var __wzf__: WzfConfig;
}
type Envs = {
    [key: string]: string | boolean | number | Envs;
};
export type UserConfig = {
    nodeServer?: {
        rds_host: string;
        rds_pwd: string;
        rds_type: "single" | "cluster" | "Sentinel";
        rds_name?: string;
        rds_db: number;
    };
    stmode: "dev" | "prod" | "smm" | "xn";
    encryption?: boolean;
    env?: Envs;
    logger?: {
        showReq: boolean;
        showRes: boolean;
    };
    server?: {
        https?: boolean;
        domain?: string;
        timeout?: number;
        open?: boolean;
        csp?: {
            /**
             * @default true
             */
            enabled: boolean;
            /**
             * csp配置项，按需修改单项
             * @default {
             *  'default-src': ["'self'"],
             *  'base-uri': ["'self'"],
             *  'font-src': ["'self'", 'https:', 'data:'],
             *  'form-action': ["'self'"],
             *  'frame-ancestors': ["'self'"],
             *  'img-src': ["'self'", 'data:'],
             *  'object-src': ["'none'"],
             *  // 'script-src': ["'self'", "'unsafe-inline'","'unsafe-eval'"],
             *  'script-src': ["'self'"],
             *  'script-src-attr': ["'none'"],
             *  'style-src': ["'self'", 'https:', "'unsafe-inline'"],
             *  'connect-src': ["'self'"],
             *  'frame-src': ["'self'"],
             *  }
             * @example {
             *  'frame-src': ["'self'", "*.jinhudao.com"],
             *  "img-src": ["'self'", '*.baidu.com']
             * }
             */
            directives?: {
                "default-src"?: string[];
                "base-uri"?: string[];
                "font-src"?: string[];
                "form-action"?: string[];
                "frame-ancestors"?: string[];
                "img-src"?: string[];
                "object-src"?: string[];
                "script-src"?: string[];
                "script-src-attr"?: string[];
                "style-src"?: string[];
                "connect-src"?: string[];
                "frame-src"?: string[];
            };
        };
    };
    proxy?: {
        [key: string]: string;
    };
    /**
     * 解决多app用户权限互通问题。
     * 配置此项后将由wzf拦截登录接口托管token，自动将token放置到配置的请求头中
     */
    authorization?: {
        /**
         * 需要拦截的登录接口url
         * @example /api/login
         */
        url: string;
        /**
         * token参数在响应体中的位置。若响应体为 {status:200,data:{token1:"t_value"}}，则值为："data.token1"
         */
        token: string;
        /**
         * token放在请求头的key。若配置为"header-token"，则由wzf代理的接口会自动加上"header-token"的请求头
         */
        header: string;
    };
    apps: {
        [key: string]: {
            port: number;
            hidePort?: boolean;
            host?: string;
            enabled?: boolean;
        };
    };
};
export type WzfConfig = {
    appName?: string;
    appsPath: string;
    wzfPath: string;
    rdsClient?: Redis | Cluster;
    cliMode: "dev" | "build" | "start";
    cliEnv: string;
} & UserConfig;
declare const _getWzfConfig: (cliMode: "dev" | "build" | "start") => Promise<WzfConfig>;
export default _getWzfConfig;
